@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of Popeye
+
 package scrub
 
 import (
@@ -40,3 +43,7 @@ func NewCluster(ctx context.Context, c *Cache, codes *issues.Codes) Sanitizer {
 func (d *Cluster) Sanitize(ctx context.Context) error {
 	return sanitize.NewCluster(d.Collector, d).Sanitize(ctx)
 }
+
+func (d *Cluster) HasMetrics() bool {
+	return d.client.HasMetrics()
+}
